@@ -26,7 +26,6 @@
 
 #include <gnome.h>
 #include <glade/glade.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-debug.h>
@@ -114,7 +113,7 @@ get_program_parameters (BasicAutotoolsPlugin *plugin,
 			gchar *local_path;
 			const gchar *rel_path;
 		
-			local_path = gnome_vfs_get_local_path_from_uri ((gchar*)node->data);
+			local_path = anjuta_util_get_local_path_from_uri ((gchar *)node->data);
 			if (local_path == NULL)
 			{
 				g_free (node->data);
@@ -287,7 +286,7 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 		/* Check if target is local */
 		gchar *local_uri;
 		
-		local_uri = gnome_vfs_get_local_path_from_uri (target);
+		local_uri = anjuta_util_get_local_path_from_uri (target);
 		if (local_uri == NULL)
 		{
 			error_condition = TRUE;
@@ -332,7 +331,7 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 		anjuta_shell_get (ANJUTA_PLUGIN (plugin)->shell, "current_editor",
 						  G_TYPE_OBJECT, &te, NULL);
 		
-		filename = gnome_vfs_get_local_path_from_uri (target);
+		filename = anjuta_util_get_local_path_from_uri (target);
 		prog = NULL;
 		prog = g_strdup (filename);
 		temp = g_strrstr (prog, ".");
@@ -393,26 +392,40 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 										   IAnjutaTerminal, NULL);
 		if (term)
 		{
-			gchar* prog_path = g_find_program_in_path("anjuta_launcher");
 			
-			if (prog_path != NULL)
+
+			if (plugin->commands[IANJUTA_BUILDABLE_COMMAND_EXECUTE])
 			{
-				gchar* oldcmd = cmd;
-			
-				cmd = g_strconcat ("anjuta_launcher ", oldcmd, NULL);
+				gchar *oldcmd = cmd;
+
+				cmd = g_strdup_printf (plugin->commands[IANJUTA_BUILDABLE_COMMAND_EXECUTE],
+					oldcmd);
+
 				g_free (oldcmd);
-				g_free (prog_path);
-			}
-			else
-			{
-				DEBUG_PRINT("Missing anjuta_launcher");
-			}
+			} else {
+				gchar* launcher_path = g_find_program_in_path("anjuta_launcher");
+
+				if (launcher_path != NULL)
+				{
+					gchar* oldcmd = cmd;
 				
-			ianjuta_terminal_execute_command (term, dir, cmd, NULL);
+					cmd = g_strconcat ("anjuta_launcher ", oldcmd, NULL);
+
+					g_free (oldcmd);
+					g_free (launcher_path);
+				}
+				else
+				{
+					DEBUG_PRINT("%s", "Missing anjuta_launcher");
+				}
+				
+			}
+
+			ianjuta_terminal_execute_command (term, dir, cmd, NULL, NULL);
 		}
 		else
 		{
-			DEBUG_PRINT ("No installed terminal plugin found");
+			DEBUG_PRINT ("%s", "No installed terminal plugin found");
 			gnome_execute_shell (dir, cmd);
 		}
 	}
