@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
@@ -36,7 +36,7 @@
 #include <libanjuta/anjuta-launcher.h>
 
 #include <glib/gstdio.h>
-#include <glib/gfileutils.h>
+#include <glib.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -117,21 +117,27 @@ npw_check_autogen (void)
  *---------------------------------------------------------------------------*/
 
 static void
-cb_autogen_write_definition (const gchar* name, const gchar* value, NPWValueTag tag, gpointer user_data)
+cb_autogen_write_definition (const gchar* name, NPWValue * node, gpointer user_data)
 {
 	FILE* def = (FILE *)user_data;
 
-	if ((tag & NPW_VALID_VALUE) && (value != NULL))
+	if ((npw_value_get_tag(node) & NPW_VALID_VALUE) && (npw_value_get_value(node) != NULL))
 	{
-		if(value[0] == '{') /* Seems to be a list, so do not quote */
-			fprintf(def, "%s = %s;\n", name, value);
+		if(npw_value_get_value (node)[0] == '{') /* Seems to be a list, so do not quote */
+		{
+			fprintf(def, "%s = %s;\n", name, npw_value_get_value (node));
+		}
 		else
-			fprintf (def, "%s = \"%s\";\n", name, value);
+		{
+			gchar *esc_value = g_strescape (npw_value_get_value (node), NULL);
+			fprintf (def, "%s = \"%s\";\n", name, esc_value);
+			g_free (esc_value);
+		}
 	}
 }
 
 gboolean
-npw_autogen_write_definition_file (NPWAutogen* this, NPWValueHeap* values)
+npw_autogen_write_definition_file (NPWAutogen* this, GHashTable* values)
 {
 	FILE* def;
 
@@ -143,7 +149,7 @@ npw_autogen_write_definition_file (NPWAutogen* this, NPWValueHeap* values)
 
 	/* Generate definition data for autogen */
 	fputs ("AutoGen Definitions .;\n",def);
-	npw_value_heap_foreach_value (values, cb_autogen_write_definition, def);
+	npw_value_heap_foreach_value (values, (GHFunc)cb_autogen_write_definition, def);
 
 	fclose (def);
 
@@ -345,7 +351,7 @@ npw_autogen_execute (NPWAutogen* this, NPWAutogenFunc func, gpointer data, GErro
 	}
 	
 	this->busy = TRUE;
-	if (!anjuta_launcher_execute_v (this->launcher, args, on_autogen_output, this))
+	if (!anjuta_launcher_execute_v (this->launcher, args, NULL, on_autogen_output, this))
 	{
 		return FALSE;
 	}
