@@ -1,3 +1,4 @@
+char *s = N_("A GNOME applet project");
 char *s = N_("A generic C++ project");
 char *s = N_("A generic GNOME project");
 char *s = N_("A generic GTK+ project");
@@ -20,6 +21,7 @@ char *s = N_("Adds support for building shared libraries in your project");
 char *s = N_("Adds support for internationalization so that your project can have translations in different languages");
 char *s = N_("Anjuta Plugin");
 char *s = N_("Anjuta plugin project that uses libanjuta framework");
+char *s = N_("Applet Title:");
 char *s = N_("Author:");
 char *s = N_("Basic information");
 char *s = N_("Berkeley Software Distribution License (BSD)");
@@ -28,14 +30,18 @@ char *s = N_("Configure external packages");
 char *s = N_("Configure external packages:");
 char *s = N_("Create a template glade interface file");
 char *s = N_("Create glade interface file");
+char *s = N_("Description:");
 char *s = N_("Destination:");
+char *s = N_("Display description of the applet");
 char *s = N_("Display description of the plugin");
+char *s = N_("Display title of the applet");
 char *s = N_("Display title of the plugin");
 char *s = N_("Django Project");
 char *s = N_("Django Project information");
 char *s = N_("Email address:");
 char *s = N_("GCJ needs to know which class contains the main() function");
 char *s = N_("GNOME");
+char *s = N_("GNOME Applet");
 char *s = N_("GTK+");
 char *s = N_("GTKmm");
 char *s = N_("General Project Information");
